@@ -20,6 +20,7 @@ from homeassistant.helpers.data_entry_flow import (
     FlowManagerIndexView,
     FlowManagerResourceView,
 )
+from homeassistant.helpers.dispatcher import async_dispatcher_connect
 from homeassistant.loader import (
     Integration,
     IntegrationNotFound,
@@ -43,6 +44,7 @@ async def async_setup(hass):
     websocket_api.async_register_command(hass, config_entries_get)
     websocket_api.async_register_command(hass, config_entry_disable)
     websocket_api.async_register_command(hass, config_entry_update)
+    websocket_api.async_register_command(hass, config_entries_subscribe)
     websocket_api.async_register_command(hass, config_entries_progress)
     websocket_api.async_register_command(hass, ignore_config_flow)
 
@@ -408,6 +410,54 @@ async def config_entries_get(
     )
 
 
+@websocket_api.websocket_command(
+    {
+        vol.Required("type"): "config_entries/subscribe",
+        vol.Optional("type_filter"): str,
+    }
+)
+@websocket_api.async_response
+async def config_entries_subscribe(
+    hass: HomeAssistant, connection: ActiveConnection, msg: dict[str, Any]
+) -> None:
+    """Subscribe to config entry updates."""
+    type_filter = msg.get("type_filter")
+
+    async def async_forward_config_entry_changes(
+        change: config_entries.ConfigEntryChange, entry: config_entries.ConfigEntry
+    ) -> None:
+        """Forward config entry state events to websocket."""
+        if type_filter:
+            integration = await async_get_integration(hass, entry.domain)
+            if integration.integration_type != type_filter:
+                return
+
+        connection.send_message(
+            websocket_api.event_message(
+                msg["id"],
+                [
+                    {
+                        "type": change,
+                        "entry": entry_json(entry),
+                    }
+                ],
+            )
+        )
+
+    current_entries = await async_matching_config_entries(hass, type_filter, None)
+    connection.subscriptions[msg["id"]] = async_dispatcher_connect(
+        hass,
+        config_entries.SIGNAL_CONFIG_ENTRY_CHANGED,
+        async_forward_config_entry_changes,
+    )
+    connection.send_result(msg["id"])
+    connection.send_message(
+        websocket_api.event_message(
+            msg["id"], [{"type": None, "entry": entry} for entry in current_entries]
+        )
+    )
+
+
 async def async_matching_config_entries(
     hass: HomeAssistant, type_filter: str | None, domain: str | None
 ) -> list[dict[str, Any]]:
