@@ -5,12 +5,7 @@ from abc import ABC
 from dataclasses import dataclass
 from typing import Any, cast
 
-from homeassistant.components.media_player import BrowseMedia
-from homeassistant.components.media_player.const import (
-    MEDIA_CLASS_APP,
-    MEDIA_TYPE_APP,
-    MEDIA_TYPE_APPS,
-)
+from homeassistant.components.media_player import BrowseMedia, MediaClass, MediaType
 from homeassistant.core import HomeAssistant, callback
 
 from .const import DOMAIN, URI_SCHEME, URI_SCHEME_REGEX
@@ -56,20 +51,20 @@ class MediaSourceItem:
             base = BrowseMediaSource(
                 domain=None,
                 identifier=None,
-                media_class=MEDIA_CLASS_APP,
-                media_content_type=MEDIA_TYPE_APPS,
+                media_class=MediaClass.APP,
+                media_content_type=MediaType.APPS,
                 title="Media Sources",
                 can_play=False,
                 can_expand=True,
-                children_media_class=MEDIA_CLASS_APP,
+                children_media_class=MediaClass.APP,
             )
             base.children = sorted(
                 (
                     BrowseMediaSource(
                         domain=source.domain,
                         identifier=None,
-                        media_class=MEDIA_CLASS_APP,
-                        media_content_type=MEDIA_TYPE_APP,
+                        media_class=MediaClass.APP,
+                        media_content_type=MediaType.APP,
                         thumbnail=f"https://brands.home-assistant.io/_/{source.domain}/logo.png",
                         title=source.name,
                         can_play=False,
