@@ -2,6 +2,7 @@
 from dataclasses import dataclass
 
 from homeassistant.components.binary_sensor import (
+    DOMAIN as BINARY_SENSOR_DOMAIN,
     BinarySensorEntity,
     BinarySensorEntityDescription,
 )
@@ -21,7 +22,11 @@ from .model import (
     RainMachineEntityDescription,
     RainMachineEntityDescriptionMixinDataKey,
 )
-from .util import key_exists
+from .util import (
+    EntityDomainReplacementStrategy,
+    async_finish_entity_domain_replacements,
+    key_exists,
+)
 
 TYPE_FLOW_SENSOR = "flow_sensor"
 TYPE_FREEZE = "freeze"
@@ -125,6 +130,27 @@ async def async_setup_entry(
     """Set up RainMachine binary sensors based on a config entry."""
     data: RainMachineData = hass.data[DOMAIN][entry.entry_id]
 
+    async_finish_entity_domain_replacements(
+        hass,
+        entry,
+        (
+            EntityDomainReplacementStrategy(
+                BINARY_SENSOR_DOMAIN,
+                f"{data.controller.mac}_freeze_protection",
+                f"switch.{data.controller.name.lower()}_freeze_protect_enabled",
+                breaks_in_ha_version="2022.12.0",
+                remove_old_entity=False,
+            ),
+            EntityDomainReplacementStrategy(
+                BINARY_SENSOR_DOMAIN,
+                f"{data.controller.mac}_extra_water_on_hot_days",
+                f"switch.{data.controller.name.lower()}_hot_days_extra_watering",
+                breaks_in_ha_version="2022.12.0",
+                remove_old_entity=False,
+            ),
+        ),
+    )
+
     api_category_sensor_map = {
         DATA_PROVISION_SETTINGS: ProvisionSettingsBinarySensor,
         DATA_RESTRICTIONS_CURRENT: CurrentRestrictionsBinarySensor,
